# Distinctiveness Centrality
A Python library to calculate Distinctiveness Centrality in social networks. 

Tutorials and code available on GitHub: https://github.com/iandreafc/distinctiveness


## Please cite as
Fronzetti Colladon, A., & Naldi, M. (2020). Distinctiveness Centrality in Social Networks. *PLoS ONE*, *15*(5), e0233276. [https://doi.org/10.1371/journal.pone.0233276](https://doi.org/10.1371/journal.pone.0233276)